All platforms.

clj-helpers.collections

Collections helper functions.

Collections helper functions.
raw docstring

find-firstclj/s

(find-first pred? coll)

Returns a first element in the collection by the given predicate.

Returns a first element in the collection by the given predicate.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries